@@ -30,6 +30,9 @@
 #include "views/viewmodecontroller.h"
 #include "views/viewproperties.h"
 
+#ifdef HAVE_KACTIVITIES
+#include <KActivities/ResourceInstance>
+#endif
 #include <KFileItemActions>
 #include <KFilePlacesModel>
 #include <KIO/PreviewJob>
@@ -40,7 +43,6 @@
 #include <KShell>
 #include <KUrlComboBox>
 #include <KUrlNavigator>
-#include <kio_version.h>
 
 #include <QDropEvent>
 #include <QLoggingCategory>
@@ -64,20 +66,20 @@ DolphinViewContainer::DolphinViewContainer(const QUrl& url, QWidget* parent) :
     m_statusBarTimer(nullptr),
     m_statusBarTimestamp(),
     m_autoGrabFocus(true)
-#ifdef KActivities_FOUND
-    , m_activityResourceInstance(0)
+#ifdef HAVE_KACTIVITIES
+    , m_activityResourceInstance(nullptr)
 #endif
 {
     hide();
 
     m_topLayout = new QVBoxLayout(this);
     m_topLayout->setSpacing(0);
-    m_topLayout->setMargin(0);
+    m_topLayout->setContentsMargins(0, 0, 0, 0);
 
     m_navigatorWidget = new QWidget(this);
     QHBoxLayout* navigatorLayout = new QHBoxLayout(m_navigatorWidget);
     navigatorLayout->setSpacing(0);
-    navigatorLayout->setMargin(0);
+    navigatorLayout->setContentsMargins(0, 0, 0, 0);
 
     m_urlNavigator = new KUrlNavigator(DolphinPlacesModelSingleton::instance().placesModel(), url, this);
     connect(m_urlNavigator, &KUrlNavigator::activated,
@@ -222,11 +224,10 @@ DolphinViewContainer::DolphinViewContainer(const QUrl& url, QWidget* parent) :
 
     // Initialize kactivities resource instance
 
-    #ifdef KActivities_FOUND
-    m_activityResourceInstance = new KActivities::ResourceInstance(
-            window()->winId(), url);
+#ifdef HAVE_KACTIVITIES
+    m_activityResourceInstance = new KActivities::ResourceInstance(window()->winId(), url);
     m_activityResourceInstance->setParent(this);
-    #endif
+#endif
 }
 
 DolphinViewContainer::~DolphinViewContainer()
@@ -244,13 +245,13 @@ void DolphinViewContainer::setActive(bool active)
     m_urlNavigator->setActive(active);
     m_view->setActive(active);
 
-    #ifdef KActivities_FOUND
+#ifdef HAVE_KACTIVITIES
     if (active) {
         m_activityResourceInstance->notifyFocusedIn();
     } else {
         m_activityResourceInstance->notifyFocusedOut();
     }
-    #endif
+#endif
 }
 
 bool DolphinViewContainer::isActive() const
@@ -470,9 +471,9 @@ void DolphinViewContainer::setUrl(const QUrl& newUrl)
         m_urlNavigator->setLocationUrl(newUrl);
     }
 
-    #ifdef KActivities_FOUND
+#ifdef HAVE_KACTIVITIES
     m_activityResourceInstance->setUri(newUrl);
-    #endif
+#endif
 }
 
 void DolphinViewContainer::setFilterBarVisible(bool visible)
