@@ -19,6 +19,7 @@
 #ifndef CONFIRMATIONSSETTINGSPAGE_H
 #define CONFIRMATIONSSETTINGSPAGE_H
 
+#include "config-terminal.h"
 #include "settings/settingspagebase.h"
 
 class QCheckBox;
@@ -47,6 +48,11 @@ private:
     QCheckBox* m_confirmMoveToTrash;
     QCheckBox* m_confirmEmptyTrash;
     QCheckBox* m_confirmDelete;
+
+#ifdef HAVE_TERMINAL
+    QCheckBox* m_confirmClosingTerminalRunningProgram;
+#endif
+
     QCheckBox* m_confirmClosingMultipleTabs;
     QCheckBox* m_confirmScriptExecution;
 };
