@@ -19,16 +19,12 @@
 
 #include "serviceitemdelegate.h"
 
-#include "dolphindebug.h"
-#include <QPushButton>
-#include <QIcon>
-
 #include "servicemodel.h"
 
 #include <QAbstractItemView>
 #include <QCheckBox>
-#include <QModelIndex>
 #include <QPainter>
+#include <QPushButton>
 
 ServiceItemDelegate::ServiceItemDelegate(QAbstractItemView* itemView, QObject* parent) :
     KWidgetItemDelegate(itemView, parent)
