@@ -19,32 +19,31 @@
  ***************************************************************************/
 
 #include "viewpropsprogressinfo.h"
-#include "applyviewpropsjob.h"
 
-#include <QLabel>
-#include <QProgressBar>
-#include <QTimer>
-#include <QVBoxLayout>
-#include <QDialogButtonBox>
-#include <QPushButton>
+#include "applyviewpropsjob.h"
+#include "views/viewproperties.h"
 
 #include <KConfigGroup>
 #include <KLocalizedString>
-#include <KIO/Job>
 
-#include <views/viewproperties.h>
+#include <QDialogButtonBox>
+#include <QLabel>
+#include <QProgressBar>
+#include <QPushButton>
+#include <QTimer>
+#include <QVBoxLayout>
 
 ViewPropsProgressInfo::ViewPropsProgressInfo(QWidget* parent,
                                              const QUrl& dir,
                                              const ViewProperties& viewProps) :
     QDialog(parent),
     m_dir(dir),
-    m_viewProps(0),
-    m_label(0),
-    m_progressBar(0),
-    m_dirSizeJob(0),
-    m_applyViewPropsJob(0),
-    m_timer(0)
+    m_viewProps(nullptr),
+    m_label(nullptr),
+    m_progressBar(nullptr),
+    m_dirSizeJob(nullptr),
+    m_applyViewPropsJob(nullptr),
+    m_timer(nullptr)
 {
     const QSize minSize = minimumSize();
     setMinimumSize(QSize(320, minSize.height()));
@@ -96,13 +95,13 @@ ViewPropsProgressInfo::ViewPropsProgressInfo(QWidget* parent,
 ViewPropsProgressInfo::~ViewPropsProgressInfo()
 {
     delete m_viewProps;
-    m_viewProps = 0;
+    m_viewProps = nullptr;
 }
 
 void ViewPropsProgressInfo::closeEvent(QCloseEvent* event)
 {
     m_timer->stop();
-    m_applyViewPropsJob = 0;
+    m_applyViewPropsJob = nullptr;
     QDialog::closeEvent(event);
 }
 
@@ -110,12 +109,12 @@ void ViewPropsProgressInfo::reject()
 {
     if (m_dirSizeJob) {
         m_dirSizeJob->kill();
-        m_dirSizeJob = 0;
+        m_dirSizeJob = nullptr;
     }
 
     if (m_applyViewPropsJob) {
         m_applyViewPropsJob->kill();
-        m_applyViewPropsJob = 0;
+        m_applyViewPropsJob = nullptr;
     }
 
     QDialog::reject();
@@ -144,7 +143,7 @@ void ViewPropsProgressInfo::applyViewProperties()
     m_label->setText(i18nc("@info:progress", "Folders: %1", subdirs));
     m_progressBar->setMaximum(subdirs);
 
-    m_dirSizeJob = 0;
+    m_dirSizeJob = nullptr;
 
     m_applyViewPropsJob = new ApplyViewPropsJob(m_dir, *m_viewProps);
     connect(m_applyViewPropsJob, &ApplyViewPropsJob::result,
